Struct FlatMap
pub struct FlatMap<St, U, F> {
inner: Flatten<Map<St, F>, U>,
}Expand description
Stream for the flat_map method.
Fields
inner: Flatten<Map<St, F>, U>Implementations
impl<St, U, F> FlatMap<St, U, F>
impl<St, U, F> FlatMap<St, U, F>
pub fn get_ref(&self) -> &St
pub fn get_ref(&self) -> &St
Acquires a reference to the underlying sink or stream that this combinator is pulling from.
pub fn get_mut(&mut self) -> &mut St
pub fn get_mut(&mut self) -> &mut St
Acquires a mutable reference to the underlying sink or stream that this combinator is pulling from.
Note that care must be taken to avoid tampering with the state of the sink or stream which may otherwise confuse this combinator.
pub fn get_pin_mut(self: Pin<&mut FlatMap<St, U, F>>) -> Pin<&mut St>
pub fn get_pin_mut(self: Pin<&mut FlatMap<St, U, F>>) -> Pin<&mut St>
Acquires a pinned mutable reference to the underlying sink or stream that this combinator is pulling from.
Note that care must be taken to avoid tampering with the state of the sink or stream which may otherwise confuse this combinator.
pub fn into_inner(self) -> St
pub fn into_inner(self) -> St
Consumes this combinator, returning the underlying sink or stream.
Note that this may discard intermediate state of this combinator, so care should be taken to avoid losing resources when this is called.